@@ -84,8 +84,8 @@ class FileStorageObject(object):
         """RDFObject for this object"""
         return self.fs._get_rdfobject(self.id, u'ROOT')
 
-    def add_part(self, partid, bytestream):
-        return self.fs._put_part(self.id, partid, bytestream)
+    def add_part(self, partid, bytestream, version=None):
+        return self.fs._put_part(self.id, partid, bytestream, version)
 
     def get_part(self, partid, stream=False, version=None):
         return self.fs._get_part(self.id, partid, stream, version)
@@ -305,9 +305,9 @@ class FileStorageClient(object):
 
     def deleteObject(self, id):
         if self.storeclient.exists(id):
-            self.storeclient.delete_object(id)
             if self.queue != None:
                 self._log(id, 'd', 'Deleting an object')
+            return self.storeclient.delete_object(id)
 
     def log_audit(self, id, logcontext, context):
         if self.queue != None:
