@@ -64,12 +64,18 @@ class URIHelper:
                     return URIRef(rdf_text.strip())
                 elif URI_SHORT.match(rdf_text.strip()):
                     prefix, tail = URI_SHORT.match(rdf_text.strip()).groups()
-                    return self.uriref_shorthand_uri(prefix, tail)
+                    try:
+                        return self.uriref_shorthand_uri(prefix, tail)
+                    except PrefixNotKnownException:
+                        if return_Literal_not_Exception:
+                            return Literal(rdf_text)
+                        else:
+                            raise URINotSetException
             if return_Literal_not_Exception:
                 return Literal(rdf_text)
             else:
-                raise URINotSetException()
-        
+                raise URINotSetException
+                    
         def get_uriref(self, rdf_text, force=False):
             """Similar to parse_uri, but no attempt is made to expand prefixes"""
             if isinstance(rdf_text, URIRef):
